REM 2006 (c) Copyright IBM Corp.
REM All Rights Reserved.

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 				  2006 (c) Copyright IBM Corp
:: 					All Rights Reserved
::   
:: OVERVIEW:
::   
:: Note this exact same script is utilized as the core install actions for
:: install and uninstall capabilities.  This file should not be utilized 
:: directly, use the install.bat and uninstall.bat instead.
::
:: This script assumes that the current working directory is the "eclipse"
:: folder for RMT and will not work properly if not run from this folder.
::
:: USAGE  installInternal.bat ["INSTALL" | "UNINSTALL"]
:: 
:: DATE		COMMENT
:: 2006.01.30	Initial adaption of script from 6.1.1.1 install scripts.
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

SET log=C:\temp\install.log
SET DEBUG_OUTPUT=0
@ECHO ON
@CALL :LogHeader Start %0
@CALL :SetGlobals %0 %1

@CALL :Main
@CALL :LogHeader End %0
REM PAUSE
GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Initialize global setting used throughout this install/uninstall 
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetGlobals
	SET ACTION=%2
	SET PROD_INSTALL=%CD%
	SET PROD_INSTALL_QUOTES="%PROD_INSTALL%"

	SET ERR_CODE=0
	SET RTMT=""
	@GOTO :EOF

:Main
	@if %ACTION% == "UPDATE_NET" (
		SET ACTION="UNINSTALL"
		CALL :RegAsmDLLs
		SET ACTION="INSTALL"
		CALL :RegAsmDLLs
		CALL :InitTestManagerSupport
	) else (
		CALL :CreateEnvSettings
		@if not %ERR_CODE% == 0 @GOTO :EOF

		CALL :RegAsmDLLs
		@if not %ERR_CODE% == 0 @GOTO :EOF

		CALL :AssociateFileTypes
		@if not %ERR_CODE% == 0 @GOTO :EOF

		CALL :InitTestManagerSupport
	)

	@GOTO :EOF

:LogHeader
	@echo "---------------- %1 %2 -----------------"
	@Date /T
	@Time /T
	@echo "Current Directory:"
	cd
	@GOTO	:EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Set Environment Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CreateEnvSettings
	CALL :DefineEnv IBM_RATIONAL_RMT_INSTALL_DIR %PROD_INSTALL_QUOTES%
	@GOTO :EOF
:DefineEnv
	@echo DefineEnv %ACTION% == "INSTALL"
	@if %ACTION% == "INSTALL" (
		CALL :SetEnv %1 %2
	) else (
		CALL :UnSetEnv %1
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   RegAsm DLLs
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:RegAsmDLLs
	SET REGASM=""
	CALL :CheckForDotNetFramework
	@IF %REGASM% == "" (
		SET ERR_CODE=1
		@echo *** No .Net Framework installed on the system.
		@GOTO :EOF
	)
	CALL :PerformRegAsm RTMTExcelImporter.dll
	CALL :PerformRegAsm RTMTRationalImporter.dll
	CALL :PerformRegAsm RTMTWordImporter.dll
	CALL :PerformGac rtMTImport.dll
	CALL :PerformGac TMSCOMSERVERLib.dll
	CALL :PerformGac Microsoft.Vbe.Interop.dll
	CALL :PerformGac Microsoft.Office.Interop.Excel.dll
	CALL :PerformGac Microsoft.Office.Interop.Word.dll
	CALL :PerformGac RTMTExcelImporter.dll
	CALL :PerformGac RTMTRationalImporter.dll
	CALL :PerformGac RTMTWordImporter.dll
	@GOTO :EOF
:PerformRegAsm
	@if %ACTION% == "INSTALL" (
		%regasm% "%1"
		@IF %ERRORLEVEL% == 0 ( 
			@echo "RegAsm succeeded"
			@GOTO :EOF
		) else (
			SET ERR_CODE=1
			@echo "RegAsm Error %ERRORLEVEL%"
		)
	) else (
		%regasm% /unregister %1
		REM Ignore failure to unregister, likely because no .Net Framework at install and not significant
	)
	@GOTO :EOF
:PerformGac
	@if %ACTION% == "INSTALL" (
		GACUtility.exe -a "%PROD_INSTALL%\%1" -o
	) ELSE (
		GACUtility.exe -a "%PROD_INSTALL%\%1" -u
	)
	@IF %ERRORLEVEL% == 0 ( 
		@ECHO GACUtility %ACTION% succeeded on "%PROD_INSTALL%\%1"
	) else (
		REM # - this seems to signal failure when it succeeds???
		REM # CALL :Debug GACUtility %ARG_ACTION% failed on "%~1\%2"
	)
	GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Associate File Types
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:AssociateFileTypes
	@if %ACTION% == "INSTALL" (
		FTYPE RationalManualTest="%PROD_INSTALL%\RTMTFileOpen.exe" "%%1"
		ASSOC .RMT=RationalManualTest
		ASSOC .EXECUTION=RationalManualTest
	) else (
		ASSOC .RMT
		ASSOC .EXECUTION
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Initialize the TestManager integration
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:InitTestManagerSupport
	@if %ACTION% == "INSTALL" (
		SET REGASM=""
		CALL :CheckForDotNetFramework
		@IF %REGASM% == "" (
			SET ERR_CODE=1
			@echo *** No .Net Framework installed on the system.
			@GOTO :EOF
		)

		@echo Initialize the TestManager integration
		.\rtTlbImporter.exe
	) else (
		@echo There is no way to disassociate with an installed TestManager
	)
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Set Environment Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:SetEnv
	@set value=%1
	@set data=%2
	@set ENV_KEY="HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" 
	rreg.exe add %ENV_KEY% /v %value% /t REG_SZ /d %data%
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 					   Un-Set Environment Variable
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UnSetEnv
	@set value=%1
	@echo Trying to remove environment variable %1
	@set ENV_KEY="HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" 
	rreg.exe delete %ENV_KEY% /v %value%
	@if errorlevel 1 (
		@echo You can ignore the above error.  It is due to the environment variable not being deleted.
		@GOTO :EOF
	)
	@GOTO :EOF
	
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: 				Check For DotNet Frame Work 
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CheckForDotNetFramework
	@SET regasm1_1=%windir%\Microsoft.NET\Framework\v1.1.4322\regasm.exe
	@SET regasm2_0=%windir%\Microsoft.NET\Framework\v2.0.50727\regasm.exe

	@CALL :CheckFileExistance %regasm2_0% QUIET
	@IF %ERR_CODE%==0 (
		@SET regasm=%regasm2_0%
		@echo "Found .Net Framework 2.0"
		@GOTO :EOF
	)

	@CALL :CheckFileExistance %regasm1_1% QUIET
	@IF %ERR_CODE%==0 (
		@SET regasm=%regasm1_1%
		@echo "Found .Net Framework 1.1"
		@GOTO :EOF
	)
	@echo "Could not find .Net Framework 2.0: %regasm2_0%"
	@echo "Could not find .Net Framework 1.1: %regasm1_1%"
	@echo "No .Net Framework found"
	@GOTO :EOF

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                                         Check For a file existance
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:CheckFileExistance
	SET ERR_CODE=0
	@IF not EXIST %1 (
		SET ERR_CODE=1
		IF "%2" == "QUIET" GOTO :EOF
		@echo ERROR:  Could not find %1
	)
	GOTO :EOF 


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::                                         Logging support
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:DEBUG
	@if %DEBUG_OUTPUT% == 1 (
		@ECHO %1 >> %LOG%
	)
	@GOTO :EOF

:EXIT_SUCCESS
	@echo "-------------------------  Install Status --------------------------- "
	@echo "%0 completed successfully."
	@GOTO	:LAST

:EXIT_WARNING
	@echo "-------------------------  Install Status --------------------------- "
	@echo "%0 Completed with Warning(s)"
	@GOTO	:LAST

:EXIT_ERROR
	@echo "-------------------------  Install Status --------------------------- "
	@echo "%0 failed  with Error : %result%"
	REM EXIT 0

:LAST
	@echo "--------------------------------------------------------------------- "
